==> graalvm-jdk-24.0.1_macos-aarch64_bin.tar.gz: jdk.graal.compiler/jdk/graal/compiler/hotspot/meta/HotSpotInvocationPluginProvider.java <==
/*
 * Copyright (c) 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package jdk.graal.compiler.hotspot.meta;

import jdk.graal.compiler.nodes.graphbuilderconf.InvocationPlugins;
import jdk.graal.compiler.nodes.spi.Replacements;

import jdk.graal.compiler.serviceprovider.LibGraalService;
import jdk.graal.compiler.serviceprovider.ServiceProvider;
import jdk.vm.ci.code.Architecture;

/**
 * Allows adding additional invocation plugins to {@link HotSpotGraphBuilderPlugins} via
 * {@link ServiceProvider}.
 */
@LibGraalService
public interface HotSpotInvocationPluginProvider {
    void registerInvocationPlugins(Architecture architecture, InvocationPlugins plugins, Replacements replacements);
}

==> graalvm-jdk-25.0.1_macos-aarch64_bin.tar.gz: jdk.graal.compiler/jdk/graal/compiler/hotspot/meta/HotSpotInvocationPluginProvider.java <==
/*
 * Copyright (c) 2022, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package jdk.graal.compiler.hotspot.meta;

import jdk.graal.compiler.nodes.graphbuilderconf.InvocationPlugins;

import jdk.graal.compiler.serviceprovider.LibGraalService;
import jdk.graal.compiler.serviceprovider.ServiceProvider;
import jdk.vm.ci.code.Architecture;

/**
 * Allows adding additional invocation plugins to {@link HotSpotGraphBuilderPlugins} via
 * {@link ServiceProvider}.
 */
@LibGraalService
public interface HotSpotInvocationPluginProvider {
    void registerInvocationPlugins(Architecture architecture, InvocationPlugins plugins);
}
